@@ -100,7 +100,9 @@ double gig_gfn(double y, double m, double beta, double lambda)
 
 /* THIS FUNCTION HAS BEEN MODIFIED TO DEAL WITH GIG_GFN (extra args) */
 
-double zeroin_gig(ax,bx,f,tol, m, beta, lambda)	/* An estimate to the root  */
+double zeroin_gig(double ax, double bx, double (*f)(double x, double m, double beta, double lambda),
+  double tol, double m, double beta, double lambda)	/* An estimate to the root  */
+#ifdef FALSE
 double ax;				/* Left border | of the range	*/
 double bx;  				/* Right border| the root is seeked*/
 /* Function under investigation	*/
@@ -109,6 +111,7 @@ double tol;				/* Acceptable tolerance	*/
 double m;                               /* specific to gig_gfn */
 double beta;                            /* specific to gig_gfn */
 double lambda;                          /* specific to gig_gfn */
+#endif
 {
   double a,b,c;				/* Abscissae, descr. see above	*/
   double fa;				/* f(a)				*/
